@@ -188,7 +188,7 @@ class Http2Parser {
                     Integer.toString(dataLength), padding));
         }
 
-        ByteBuffer dest = output.startRequestBodyFrame(streamId, payloadSize, endOfStream);
+        ByteBuffer dest = output.startRequestBodyFrame(streamId, dataLength, endOfStream);
         if (dest == null) {
             swallowPayload(streamId, FrameType.DATA.getId(), dataLength, false, buffer);
             // Process padding before sending any notifications in case padding
@@ -201,7 +201,7 @@ class Http2Parser {
             }
         } else {
             synchronized (dest) {
-                if (dest.remaining() < payloadSize) {
+                if (dest.remaining() < dataLength) {
                     // Client has sent more data than permitted by Window size
                     swallowPayload(streamId, FrameType.DATA.getId(), dataLength, false, buffer);
                     if (Flags.hasPadding(flags)) {
@@ -785,7 +785,7 @@ class Http2Parser {
         HpackDecoder getHpackDecoder();
 
         // Data frames
-        ByteBuffer startRequestBodyFrame(int streamId, int payloadSize, boolean endOfStream) throws Http2Exception;
+        ByteBuffer startRequestBodyFrame(int streamId, int dataLength, boolean endOfStream) throws Http2Exception;
 
         void endRequestBodyFrame(int streamId, int dataLength) throws Http2Exception, IOException;
 
